mobile_scanner library
Classes
- Address
- An address.
- Barcode
- Represents a single recognized barcode and its value.
- BarcodeBytes
- Represents the raw bytes of a barcode.
- BarcodeCapture
- This class represents a scanned barcode.
- BarcodeOverlay
- This widget represents an overlay that paints the bounding boxes of detected barcodes.
- BarcodePainter
- A CustomPainter that draws the barcode as an outlined barcode box with rounded corners and a displayed value.
- CalendarEvent
- A calendar event extracted from a QRCode.
- ContactInfo
- A person's or organization's business card. For example a VCARD.
- DecodedBarcodeBytes
- Decoded barcode bytes, available on Android and web.
- DecodedVisionBarcodeBytes
- Decoded barcode bytes from the Apple Vision API.
- DriverLicense
- A driver license or ID card.
- An email message from a 'MAILTO:' or similar QRCode type.
- GeoPoint
-
GPS coordinates from a
GEO:or similar QRCode type. - MobileScanner
- This widget displays a live camera preview for the barcode scanner.
- MobileScannerController
- The controller for the MobileScanner widget.
- MobileScannerErrorDetails
- The raw error details for a MobileScannerException.
- MobileScannerPlatform
-
The platform interface for the
mobile_scannerplugin. - MobileScannerState
- This class represents the current state of a MobileScannerController.
- MobileScannerViewAttributes
- This class defines the attributes for the mobile scanner view.
- PersonName
- A person's name, divided into individual components.
- Phone
- Phone number information from a barcode.
- ScanWindowOverlay
- This widget represents an overlay that paints a scan window cutout.
- ScanWindowPainter
- This class represents a CustomPainter that draws a scanWindow rectangle.
- ScanWindowUtils
- A utility class for calculating scan window sizes.
- SelectCamera
- An implementation of SwitchCameraOption that selects a specific camera direction and/or lens type.
- SMS
-
An sms message from a
SMS:or similar QRCode type. - StartOptions
- This class defines the different start options for the mobile scanner.
- SwitchCameraOption
- The options for a switch camera request.
- ToggleDirection
- An implementation of SwitchCameraOption that toggles between CameraFacing.front and CameraFacing.back.
- ToggleLensType
- An implementation of SwitchCameraOption that cycles through available lens types on the current camera facing direction.
- UrlBookmark
-
A URL and title from a
MEBKM:or similar QRCode type. - WiFi
- Wireless network information from BarcodeType.wifi barcodes.
Enums
- AddressType
- Address type constants.
- BarcodeFormat
- This enum defines the different barcode formats.
- BarcodeType
- Barcode value type constants.
- CameraFacing
- The facing of a camera.
- CameraLensType
- The type of camera lens based on focal length.
- DetectionSpeed
- The detection speed of the scanner.
- EmailType
- Email format type constants.
- EncryptionType
- Wifi encryption type constants.
- MobileScannerAuthorizationState
- The authorization state of the scanner.
- MobileScannerErrorCode
- This enum defines the different error codes for the mobile scanner.
- PhoneType
- Phone number format type constants.
- TorchState
- The state of the flashlight.
Functions
Exceptions / Errors
- MobileScannerBarcodeException
- This class represents an exception thrown by the MobileScannerController when a barcode scanning error occurs when processing an input frame.
- MobileScannerException
- This class represents an exception thrown by the MobileScannerController.